#[non_exhaustive]pub enum EffectClass {
Inspect,
Compute,
Persist,
Emit,
Control,
}Expand description
Runtime-facing side-effect classification for an operation receipt.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Inspect
Reads or inspects data without intending to mutate durable state.
Compute
Computes output from input without intending to touch durable state.
Persist
Mutates local durable state.
Emit
Produces an externally visible side effect.
Control
Changes runtime control flow or runtime-owned bookkeeping.
Implementations
Sourceimpl EffectClass
impl EffectClass