Module store_effect

Module store_effect 

Batpak-backed EffectBackend for syncbat operation effects.

This is the production capability backend: an operation’s Ctx event-append handle performs through this, which appends the event to one batpak store coordinate. The runtime owns this backend and exposes it to a handler only through Ctx, so an operation’s appends are mediated and observed.

Structs

StoreEffectBackend
Batpak store-backed effect backend bound to one append coordinate.